#
# spec file for package ghc-cborg
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cborg
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.6.0
Release:        bp155.2.15
Summary:        Concise Binary Object Representation (CBOR)
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-half-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-vector-devel
%endif

%description
This package provides an efficient implementation of the Concise Binary Object
Representation (CBOR), as specified by [RFC
7049](https://tools.ietf.org/html/rfc7049).

If you are looking for a library for serialisation of Haskell values, have a
look at the [serialise](/package/serialise) package, which is built upon this
library.

An implementation of the standard bijection between CBOR and JSON is provided
by the [cborg-json](/package/cborg-json) package. Also see
[cbor-tool](/package/cbor-tool) for a convenient command-line utility for
working with CBOR data.

This package was formerly known as 'binary-serialise-cbor'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE.txt

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Sat Nov 20 2021 Peter Simons <psimons@suse.com>
- Update cborg to version 0.2.6.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update cborg to version 0.2.6.0.
  [#]# 0.2.6.0  -- 2021-10-31
  * Support for GHC 9.2
  * Support for `text-2.0` and zero-copy `Text` serialisation support
  [#]# 0.2.5.0  -- 2021-04-08
  * Support for `ghc-bignum` and GHC 9.0
  [#]# 0.2.4.0  -- 2021-07-05
  * Fix decoding on 32-bit systems (#244)
* Fri Sep  3 2021 psimons@suse.com
- Update cborg to version 0.2.5.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Apr  9 2021 psimons@suse.com
- Update cborg to version 0.2.5.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/cborg-0.2.5.0/src/ChangeLog.md
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov 10 2020 Ondřej Súkup <mimi.vx@gmail.com>
- relax dep constraints
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jul  8 2020 psimons@suse.com
- Add cborg at version 0.2.4.0.
